@@ -195,7 +195,7 @@ struct Optimizer<'a, M> {
     /// Used for inlining.
     lits: AHashMap<Id, Box<Expr>>,
 
-    vars_for_inlining: AHashMap<Id, Box<Expr>>,
+    vars_for_inlining: FxHashMap<Id, Box<Expr>>,
 
     vars_for_prop_hoisting: AHashMap<Id, Box<Expr>>,
     /// Used for `hoist_props`.
@@ -703,6 +703,10 @@ where
 
         self.compress_cond_to_logical_ignoring_return_value(e);
 
+        self.drop_unused_update(e);
+
+        self.drop_unused_op_assign(e);
+
         match e {
             Expr::This(_) | Expr::Invalid(_) | Expr::Lit(..) => {
                 if cfg!(feature = "debug") {
